# Trusty
A persistent dictionary

## Example Usage
```
import os
import trusty

# Create an instance of a trusty dictionary. We can treat this exactly
# as we treat a Python dictionary.
pack = trusty.get('pack')

# Set some key/value paris in the TrustyDictionary.
pack['food'] = 'lembas'

# Calling .save() will persist the dictionary to disk.
pack.save()

# Confirm that the dictionary was stored at .location()
print(pack.location())
print(os.path.exists(pack.location()))
```

In a completely new Python session, we can retrieve the dictionary like so:
```
import trusty

pack = trusty.get('pack')
print(pack)

# We can then further edit the data.
pack['supplies'] = 'taters'

# Calling .save() will persist the current state back to disk.
pack.save()
```

By default, trusty will store to the following locations:

- Windows: `APPDATA/trusty`
- Linux: `$HOME/.trusty`
- Mac: `Documents/trusty`

To change this behavior, in Linux simply set the `TRUSTY_PATH` environmental variable.
```
# This will have trusty persist to /tmp/.trusty/<dictionary_name>.json
export TRUSTY_PATH='/tmp'
```
