import os
import sys
import json

TRUSTY_PATH = 'TRUSTY_PATH'
STORAGE_DIRECTORY = os.environ.get(TRUSTY_PATH, None)

if sys.platform == 'linux' or sys.platform == 'linux2':
    if TRUSTY_PATH in os.environ:
        STORAGE_DIRECTORY = os.path.join(
            os.path.expandvars(STORAGE_DIRECTORY),
            '.trusty',
        )

    else:
        STORAGE_DIRECTORY = os.path.join(
            os.environ['HOME'],
            '.trusty',
        )

elif sys.platform == 'win32':
    STORAGE_DIRECTORY = os.path.join(
        os.environ.get('APPDATA'),
        'trusty',
    )

elif sys.platform == 'darwin':
    STORAGE_DIRECTORY = os.path.join(
        os.environ['HOME'],
        'Documents',
        'trusty',
    )

else:
    raise Exception(
        (
            'Trusty requires an environmental variable (%s)'
            'specifying the storage directory location'
        ) % (
            TRUSTY_PATH,
        )
    )

def get(identifier, *args, **kwargs):
    return TrustyDictionary(identifier, *args, **kwargs)

class TrustyDictionary(dict):
    def __init__(self, identifier, *args, **kwargs):
        super(TrustyDictionary, self).__init__(*args, **kwargs)
        self.identifier = identifier
        self.load()

    def load(self):
        if os.path.exists(self.location()):
            with open(self.location(), 'r') as f:
                self.update(json.load(f))

    def save(self):
        if not os.path.exists(STORAGE_DIRECTORY):
            os.makedirs(STORAGE_DIRECTORY)
        try:
            data = json.dumps(
                self,
                indent=4,
                sort_keys=True,
            )

        except BaseException:
            raise Exception(
                'Could not encode the data within the Trusty Dictionary to '
                'JSON. Please ensure any stored data can be serialised to JSON.'
            )

        with open(self.location(), 'w') as f:
            f.write(data)

    def location(self):
        return os.path.join(
            STORAGE_DIRECTORY,
            '%s.json' % (
                self.identifier,
            ),
        )
